@@ -410,6 +410,28 @@ sub rename {
     }
 }
 
+around BUILDARGS => sub {
+    my $orig  = shift;
+    my $class = shift;
+    my @args  = @_;
+
+    try {
+        return $class->$orig(@args);
+    }
+    catch {
+        my $msg = $_;
+        $msg .= "\nArgs are:\n";
+        my $cnt = 0;
+        my @pref = ( "  Key: ", "       Val: " );
+
+        for my $arg (@args) {
+            $msg .= $pref[$cnt] . $arg . "\n";
+            $cnt = 1 - $cnt;
+        }
+        die $msg;
+    };
+};
+
 package HPCI::File::Classes;
 
 use MooseX::Role::Parameterized;
